==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebRowToggleEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebRowToggleEventArgsDetailDescription } from "./WebRowToggleEventArgsDetailDescription";
/**
 * @hidden
 */
var WebRowToggleEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebRowToggleEventArgsDetailDescriptionMetadata, _super);
    function WebRowToggleEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRowToggleEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebRowToggleEventArgsDetailDescriptionMetadata.a == null) {
            WebRowToggleEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRowToggleEventArgsDetailDescriptionMetadata.c(WebRowToggleEventArgsDetailDescriptionMetadata.a);
        }
        if (a.j(WebRowToggleEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.y(WebRowToggleEventArgsDetailDescriptionMetadata.a);
    };
    WebRowToggleEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:RowToggleEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("RowID", "Unknown");
        a.item("Expanded", "Boolean");
        a.item("Cancel", "Boolean");
    };
    WebRowToggleEventArgsDetailDescriptionMetadata.d = function (a) {
        WebRowToggleEventArgsDetailDescriptionMetadata.b(a);
        a.aa("WebRowToggleEventArgsDetail", function () { return new WebRowToggleEventArgsDetailDescription(); });
        a.z("WebRowToggleEventArgsDetail", WebRowToggleEventArgsDetailDescriptionMetadata.a);
    };
    WebRowToggleEventArgsDetailDescriptionMetadata.$t = markType(WebRowToggleEventArgsDetailDescriptionMetadata, 'WebRowToggleEventArgsDetailDescriptionMetadata');
    WebRowToggleEventArgsDetailDescriptionMetadata.a = null;
    return WebRowToggleEventArgsDetailDescriptionMetadata;
}(Base));
export { WebRowToggleEventArgsDetailDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebRowToggleEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebRowToggleEventArgsDetailDescription } from "./WebRowToggleEventArgsDetailDescription";
/**
 * @hidden
 */
var WebRowToggleEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebRowToggleEventArgsDetailDescriptionMetadata, _super);
    function WebRowToggleEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRowToggleEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebRowToggleEventArgsDetailDescriptionMetadata.a == null) {
            WebRowToggleEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRowToggleEventArgsDetailDescriptionMetadata.c(WebRowToggleEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebRowToggleEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebRowToggleEventArgsDetailDescriptionMetadata.a);
    };
    WebRowToggleEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:RowToggleEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("RowID", "Unknown");
        a.item("Expanded", "Boolean");
        a.item("Cancel", "Boolean");
    };
    WebRowToggleEventArgsDetailDescriptionMetadata.d = function (a) {
        WebRowToggleEventArgsDetailDescriptionMetadata.b(a);
        a.ac("WebRowToggleEventArgsDetail", function () { return new WebRowToggleEventArgsDetailDescription(); });
        a.ab("WebRowToggleEventArgsDetail", WebRowToggleEventArgsDetailDescriptionMetadata.a);
    };
    WebRowToggleEventArgsDetailDescriptionMetadata.$t = markType(WebRowToggleEventArgsDetailDescriptionMetadata, 'WebRowToggleEventArgsDetailDescriptionMetadata');
    WebRowToggleEventArgsDetailDescriptionMetadata.a = null;
    return WebRowToggleEventArgsDetailDescriptionMetadata;
}(Base));
export { WebRowToggleEventArgsDetailDescriptionMetadata };
